#ifndef _GT_521F32_DEFS_H_
#define _GT_521F32_DEFS_H_
/**
 * GT-521F32  Optical Finger Recognition EMBEDDED Module
 * Value definitions
 */
/* Command Summary */
#define CMD_OPEN               0x01 // Initialization
#define CMD_CLOSE              0x02 // Termination
#define CMD_USB_INTERNAL_CHECK 0x03 // Check if the connected USB device is valid
#define CMD_CHANGE_BAURDRATE   0x04 // Change UART baud rate
#define CMD_CMOS_LED           0x12 // Control CMOS LED
#define CMD_GET_ENROLL_COUNT   0x20 // Get enrolled fingerprint count
#define CMD_CHECK_ENROLLED     0x21 // Check whether the specified ID is already enrolled
#define CMD_ENROLL_START       0x22 // Start an enrollment
#define CMD_ENROLL1            0x23 // Make 1st template for an enrollment
#define CMD_ENROLL2            0x24 // Make 2nd template for an enrollment
#define CMD_ENROLL3            0x25 // Make 3rd template for an enrollment
                                    // merge three templates into one template, 
                                    // save merged template to the database
#define CMD_IS_PRESS_FINGER    0x26 // Check if a finger is placed on the sensor
#define CMD_DELETE_ID          0x40 // Delete the fingerprint with the specified ID
#define CMD_DELETE_ALL         0x41 // Delete al fingerpritns from the database
#define CMD_VERIFY             0x50 // 1:1 Verification of the capture fingerprint image
                                    // with the specified ID
#define CMD_IDENTIFY           0x51 // 1:N Idenfification of the capture fingerprint image
                                    // with the database
#define CMD_VERIFY_TEMPLATE    0x52 // 1:1 Verification of a fingerprint template with
                                    // the specified ID
#define CMD_IDENTIFY_TEMPLATE  0x53 // 1:N Idenfification of a fingerprint template
                                    // with the database
#define CMD_CAPTURE_FINGER     0x60 // Capture a fingerprint image (256x256) form 
                                    // the sensor
#define CMD_MAKE_TEMPLATE      0x61 // Make template fro transmission
#define CMD_GET_IMAGE          0x62 // Download the captured fingerprint
                                    // image (256x256)
#define CMD_GET_RAW_IMAGE      0x63 // Capture & Download raw fingerprint
                                    // image (320x240)
#define CMD_GET_TEMPLATE       0x70 // Downlaod the template of the specified ID
#define CMD_SET_TEMPLATE       0x71 // Upload the template of the specified ID
#define CMD_GET_DATABASE_START 0x72 // Start database download, "OBSOLETE"
#define CMD_GET_DATABASE_END   0x73 // End database download, "OBSOLETE"
#define CMD_SET_SECURITY_LEVEL 0xF0 // Set Security Level
#define CMD_GET_SECURITY_LEVEL 0xF1 // Get Security Level
#define CMD_IDENTIFY_TEMPLATE2 0xF4 // Identify of the capture fingerprint image with
                                    // the specified template
#define CMD_ENTER_STANDBY_MODE 0xF9 // Enter Standby Mode (Low power mode)
#define CMD_ACK                0x30 // Acknowledge.
#define CMD_NACK               0x31 // Non-acknowledge.    
    
/* Protocol: Error Codes */
#define NACK_TIMEOUT               0x1001 // "OBSOLETE", capture time
#define NACK_INVALID_BAUDRATE      0x1002 // "OBSOLETE", Invalid serial baud rate
#define NACK_INVALID_POS           0x1003 // The specified ID is not between 0~999
#define NACK_IS_NOT_USED           0x1004 // The specified ID is not used
#define NACK_IS_ALREADY_USED       0x1005 // The specified ID is already used
#define NACK_COMM_ERR              0x1006 // Communiction Error
#define NACK_VERIFY_FAILED         0x1007 // 1:1 Verification Failure
#define NACK_IDENTIFY_FAILED       0x1008 // 1:N Identification Failure
#define NACK_DB_IS_FULL            0x1009 // The database is full
#define NACK_DB_IS_EMPTY           0x100A // The database is empty
#define NACK_TURN_ERR              0x100B // "OBSOLETE", Invalid order of the enrollment
                                          // (The order was not as:
                                          // EnrollStart->Enroll1->Enroll2->Enroll3
#define NACK_BAD_FINGER            0x100C // Too bad fingerprint
#define NACK_ENROLL_FAILED         0x100D // Enrollment Failure
#define NACK_IS_NOT_SUPPORTED      0x100E // The specified command is not supported
#define NACK_DEV_ERR               0x100F // Device Error, especially if Crypto-Chip is trouble
#define NACK_CAPTURE_CANCELED      0x1010 // "OBSOLETE", The capturing is canceled
#define NACK_INVALID_PARAM         0x1011 // Invalid parameter
#define NACK_FINGER_IS_NOT_PRESSED 0x1012 // Finger is not pressed
    
/* duplicated ID */
/** 
 * Value between 0 ~ 2999 means Dupliated ID
 * There is duplicated fingerprint (while enrollment or setting template),
 * This error describes just duplicated ID
 */

/* baud count
 * bus clock 24MHz = 48,000,000
 * uart sampling    = 16
 * baud rate        = 9600
 * baud_count_9600  = 48,000,000 / 16 / 9600 = 312.5
 */
#define BAUD_COUNT_9600         313
#define BAUD_COUNT_19200        156
#define BAUD_COUNT_38400        78
#define BAUD_COUNT_57600        52
#define BAUD_COUNT_115200        26
    
    
#endif /* _GT_521F32_DEFS_H_ */

/* [] END OF FILE */
